#!/usr/bin/python
import vot
import sys
from tracker import Tracker
from networks import FeatureExtractor
import config
import os
from utils import default_loader, list_models, get_axis_aligned_bbox

handle = vot.VOT("polygon")
Polygon = handle.region()

imagefile = handle.frame()
if not imagefile:
    sys.exit(0)

feature_net = FeatureExtractor()
tracker = Tracker(feature_net, is_debug=False)
model_path = os.path.join(os.path.realpath(os.path.dirname(__file__)), config.model_dir, 'ROAMpp.torch')
tracker.load_models(model_path)

init_box = get_axis_aligned_bbox(Polygon)
init_image = default_loader(imagefile)
tracker.initialize(init_image, init_box)

while True:
    imagefile = handle.frame()
    if not imagefile:
        break
    image = default_loader(imagefile)
    bbox = tracker.track(image)
    region = vot.Rectangle(bbox[0], bbox[1], bbox[2], bbox[3])
    handle.report(region)
